import{_ as n}from"./NewEditor-llqQDWrH.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8b6e6208-1441-477e-b1d8-beebd1fdc78c",e._sentryDebugIdIdentifier="sentry-dbid-8b6e6208-1441-477e-b1d8-beebd1fdc78c")}catch{}})();var r=n(()=>`
  /* Font Awesome icon styling - consolidated */
  .label-icon {
    display: inline-block;
    height: 1em;
    overflow: visible;
    vertical-align: -0.125em;
  }
  
  .node .label-icon path {
    fill: currentColor;
    stroke: revert;
    stroke-width: revert;
  }
`,"getIconStyles");export{r as g};
//# sourceMappingURL=chunk-FMBD7UC4-D1XrumFG.js.map
