import{_ as m}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-e-lImNC1.js";import{B as y}from"./BaseLayout-DB8SD_oU.js";import{e as l,V as _,a3 as b,aO as u,aJ as v,aK as g,g as f,f as h,k as o,M as s,S as w,ag as S,n as k,w as n,ak as B,v as i,p as I}from"./jwt-decode.esm-CzNJpMna.js";import{u as $}from"./editor-BONJwSEi.js";import{A as L}from"./index-XfNkt2Vz.js";import"./logo-BiWG9_W5.js";import"./Logo-DoFepIVD.js";import"./ts.worker-yzRZJ3oC.js";import"./workspaceStore-CfaRGIsm.js";import"./userStore-awX4g_0u.js";import"./runnerData-y7ODBKD6.js";import"./url-DUHlB_Eu.js";import"./colorHelpers-DqllhzUB.js";import"./useCodebaseEvents-BuuUH-Ws.js";import"./contracts.generated-BZkyx5I1.js";import"./files-Ct7nmjM6.js";import"./linters-OxxHWdz7.js";import"./asyncComputed-tYnPAAjo.js";import"./PhBug.vue-DYWFmbAE.js";import"./router-8Vfxs13r.js";import"./constants-CmgnxxPp.js";import"./index-2y0Q0tZ3.js";import"./index-DvntD8BL.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="8c24975d-14b4-4f19-af7e-fa36ba2a2d13",e._sentryDebugIdIdentifier="sentry-dbid-8c24975d-14b4-4f19-af7e-fa36ba2a2d13")}catch{}})();const x=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"var(--ac-brand-primary)"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),D={class:"v-spinner"};function K(e,r,a,d,p,c){return v((f(),h("div",D,[o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const P=u(x,[["render",K],["__scopeId","data-v-224007fd"]]),R={class:"content"},z=l({__name:"ProjectLogin",setup(e){const r=B(),a=S(),d=$();function p(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function c(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=c();if(!t){a.push({name:"error"});return}await d.createLogin(t).then(p),a.push({name:"editor"})}),(t,A)=>(f(),k(y,null,{navbar:n(()=>[i(I(L),{style:{padding:"5px 25px",border:"1px solid var(--ac-border-subtle)"}},{title:n(()=>[i(m)]),_:1})]),content:n(()=>[o("div",R,[i(P)])]),_:1}))}}),oe=u(z,[["__scopeId","data-v-c9eeae4b"]]);export{oe as default};
//# sourceMappingURL=ProjectLogin-Cld64TmU.js.map
