import{N as c}from"./Navbar-Dfkefn8Y.js";import{e as d,ak as u,b as a,l,a6 as f,f as _,g as y,v as p,k as I,aO as b}from"./jwt-decode.esm-CzNJpMna.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-Bb3vA821.js";import"./constants-CmgnxxPp.js";import"./PhCaretDown.vue-9p0Oo0y4.js";import"./PhPencilSimple.vue-BJVpQqAs.js";import"./router-W58Zb32N.js";import"./ts.worker-yzRZJ3oC.js";import"./organization-Dv2gjYZs.js";import"./tables-B14bH8Kr.js";import"./string-KT3da_dt.js";import"./keyboard-Bg8-S3FC.js";import"./os-D0_XKBIS.js";import"./projectStore-1e9Bdcb1.js";import"./project-CUN2uQd6.js";import"./organizationSwitcher-CIDAicHA.js";import"./cascaderStore-foIVwCGb.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-CBzjPM9l.js";import"./member-DZQbFOdZ.js";import"./index-B87jgww1.js";import"./index-zwdtp9eM.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-CZG1pohE.js";import"./PhNotePencil.vue-CXSx5Zo1.js";import"./PhSignOut.vue-BpDijczZ.js";import"./index-2y0Q0tZ3.js";import"./index-DvntD8BL.js";import"./PhPlus.vue-DpmzceUz.js";import"./omniChatStore-D4AqaYvz.js";import"./files-Ct7nmjM6.js";import"./contracts.generated-BZkyx5I1.js";import"./runnerData-y7ODBKD6.js";import"./url-DUHlB_Eu.js";import"./colorHelpers-DqllhzUB.js";import"./uuid-B4_ctPXu.js";import"./PhCopySimple.vue-CVMuu27m.js";import"./PhSparkle.vue-BhLTj2ma.js";import"./index-XfNkt2Vz.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="83b02225-a85f-47df-9617-c13fce260c98",r._sentryDebugIdIdentifier="sentry-dbid-83b02225-a85f-47df-9617-c13fce260c98")}catch{}})();const v={class:"console-layout"},g={class:"console-content"},w=d({__name:"ConsoleLayout",setup(r){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,e=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(e)return{organizationId:e}});return(t,i)=>{const e=f("RouterView");return y(),_("div",v,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),I("div",g,[p(e)])])}}}),io=b(w,[["__scopeId","data-v-62f8634d"]]);export{io as default};
//# sourceMappingURL=ConsoleLayout-BosB_wi8.js.map
