import{e as d,b as s,f as l,g as i,k as r,h as f,M as u,K as a,aO as c}from"./jwt-decode.esm-CzNJpMna.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="43f788d8-52b2-4433-9083-5cf16b581506",e._sentryDebugIdIdentifier="sentry-dbid-43f788d8-52b2-4433-9083-5cf16b581506")}catch{}})();const y=d({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean},flexLayout:{type:Boolean},innerPadding:{}},setup(e){const n=e,t=s(()=>({...n.innerPadding&&{padding:n.innerPadding}}));return(o,g)=>(i(),l("div",{class:a(["content-layout",{"no-padding":e.noPadding}])},[r("div",{class:a(["centered-layout",{"full-width":e.fullWidth,"flex-layout":e.flexLayout}]),style:u(t.value)},[f(o.$slots,"default",{},void 0,!0)],6)],2))}}),b=c(y,[["__scopeId","data-v-00e066e8"]]);export{b as C};
//# sourceMappingURL=ContentLayout-Cco-2V__.js.map
