import{_ as i}from"./NewEditor-llqQDWrH.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="0b3739e9-88c0-423c-9d77-271ad09f3787",t._sentryDebugIdIdentifier="sentry-dbid-0b3739e9-88c0-423c-9d77-271ad09f3787")}catch{}})();var e,n=(e=class{constructor(s){this.init=s,this.records=this.init()}reset(){this.records=this.init()}},i(e,"ImperativeState"),e);export{n as I};
//# sourceMappingURL=chunk-QZHKN3VN-DXG3ZOFT.js.map
