import{_ as d,e as u,l as w}from"./NewEditor-llqQDWrH.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7663c982-59fe-4db3-bdac-a84d7d0e7927",e._sentryDebugIdIdentifier="sentry-dbid-7663c982-59fe-4db3-bdac-a84d7d0e7927")}catch{}})();var l=d((e,t,i,r)=>{e.attr("class",i);const{width:o,height:n,x:s,y:c}=h(e,t);u(e,n,o,r);const a=f(s,c,o,n,t);e.attr("viewBox",a),w.debug(`viewBox configured: ${a} with padding: ${t}`)},"setupViewPortForSVG"),h=d((e,t)=>{const i=e.node()?.getBBox()||{width:0,height:0,x:0,y:0};return{width:i.width+t*2,height:i.height+t*2,x:i.x,y:i.y}},"calculateDimensionsWithPadding"),f=d((e,t,i,r,o)=>`${e-o} ${t-o} ${i} ${r}`,"createViewBox");export{l as s};
//# sourceMappingURL=chunk-KX2RTZJC-C4yHFfIe.js.map
