import{O as i}from"./workspaceStore-CfaRGIsm.js";import{e as l,S as u,f as _,v as o,w as n,p as a,am as f,T as p,q as r,t as s,l as c,g as m}from"./jwt-decode.esm-CzNJpMna.js";import"./userStore-awX4g_0u.js";import"./runnerData-y7ODBKD6.js";import"./url-DUHlB_Eu.js";import"./colorHelpers-DqllhzUB.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="64a4c8dc-ecc1-438e-a12a-c4de06ec4e31",e._sentryDebugIdIdentifier="sentry-dbid-64a4c8dc-ecc1-438e-a12a-c4de06ec4e31")}catch{}})();const D=l({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new i().logoutCallback()}),(t,d)=>(m(),_("div",null,[o(a(f),null,{default:n(()=>[r(s(a(c).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(a(p),null,{default:n(()=>[r(s(a(c).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLogoutCallback-BhjUipkD.js.map
