import{e as c,b as o,f as t,j as r,K as d,t as f,bh as g,g as s,aO as u}from"./jwt-decode.esm-CzNJpMna.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="68755315-c94e-4849-823a-f0d87af28e37",e._sentryDebugIdIdentifier="sentry-dbid-68755315-c94e-4849-823a-f0d87af28e37")}catch{}})();const m={class:"logo"},y=["src","alt"],b=c({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){g(l=>({v4521d904:n.value}));const a=e,n=o(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),i=o(()=>`${a.brandName} Logo`);return(l,p)=>(s(),t("div",m,[e.imageUrl?(s(),t("img",{key:0,class:"logo-img",src:e.imageUrl,alt:i.value},null,8,y)):r("",!0),e.hideText?r("",!0):(s(),t("span",{key:1,class:d(e.size)},f(e.brandName),3))]))}}),_=u(b,[["__scopeId","data-v-8f34aac0"]]);export{_ as L};
//# sourceMappingURL=Logo-DoFepIVD.js.map
