import{_ as i}from"./NewEditor-llqQDWrH.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b1786899-e304-46b5-870a-0e6bec46eeff",e._sentryDebugIdIdentifier="sentry-dbid-b1786899-e304-46b5-870a-0e6bec46eeff")}catch{}})();function c(e,t){e.accDescr&&t.setAccDescription?.(e.accDescr),e.accTitle&&t.setAccTitle?.(e.accTitle),e.title&&t.setDiagramTitle?.(e.title)}i(c,"populateCommonDb");export{c as p};
//# sourceMappingURL=chunk-4BX2VUAB-ByFuOT3R.js.map
