import"./jwt-decode.esm-CzNJpMna.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="db605176-f5f3-45f0-a52b-ff12d703e964",t._sentryDebugIdIdentifier="sentry-dbid-db605176-f5f3-45f0-a52b-ff12d703e964")}catch{}})();const e={HOMEPAGE:"https://abstra.io",DOCS:"https://abstra.io/docs",CLOUD:"https://cloud.abstra.io",GITHUB:"https://github.com/abstra-app/abstra-lib"},n=t=>{if(!t)return e.DOCS;const s=t.startsWith("/")?t.slice(1):t;return`${e.DOCS}/${s}`};export{e as A,n as b};
//# sourceMappingURL=constants-CmgnxxPp.js.map
