.container[data-v-e7c84b24]{display:flex;flex-direction:column;height:100vh}.content[data-v-e7c84b24]{display:flex;align-items:center;justify-content:center;margin:auto 0;box-sizing:border-box}.card[data-v-e7c84b24]{background-color:var(--ac-bg-primary);padding:30px;border-radius:8px;border:1px solid var(--ac-border-primary);width:600px}
