import{s as b,x as g,b as a}from"./jwt-decode.esm-CzNJpMna.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="0e7bad8a-fc61-4fa8-83bf-31608df869c3",n._sentryDebugIdIdentifier="sentry-dbid-0e7bad8a-fc61-4fa8-83bf-31608df869c3")}catch{}})();const v=n=>{const e=b({loading:!0,result:null,error:null});let l=null,o=0;const u=(r,t)=>(t===o&&(e.value={loading:!1,result:r,error:null}),r),d=(r,t)=>{t===o&&r.name!=="AbortError"&&(e.value={loading:!1,result:null,error:r})},s=async()=>{l&&l.abort(),l=new AbortController;const r=++o;return e.value={loading:!0,result:e.value.result,error:null},n().then(t=>u(t,r)).catch(t=>d(t,r))};s(),g(()=>{l&&l.abort()});const f=a(()=>e.value.loading),c=a(()=>e.value.result),i=a(()=>e.value.error);return{loading:f,result:c,error:i,refetch:s}};export{v as a};
//# sourceMappingURL=asyncComputed-tYnPAAjo.js.map
