import{conf as i,language as e}from"./typescript-BWYUn8hP.js";import"./editor.main-CrZyj95l.js";import"./jwt-decode.esm-CzNJpMna.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="688a3e81-35bc-4c2b-b705-2ad944784191",t._sentryDebugIdIdentifier="sentry-dbid-688a3e81-35bc-4c2b-b705-2ad944784191")}catch{}})();var d=i,c={defaultToken:"invalid",tokenPostfix:".js",keywords:["break","case","catch","class","continue","const","constructor","debugger","default","delete","do","else","export","extends","false","finally","for","from","function","get","if","import","in","instanceof","let","new","null","return","set","super","switch","symbol","this","throw","true","try","typeof","undefined","var","void","while","with","yield","async","await","of"],typeKeywords:[],operators:e.operators,symbols:e.symbols,escapes:e.escapes,digits:e.digits,octaldigits:e.octaldigits,binarydigits:e.binarydigits,hexdigits:e.hexdigits,regexpctl:e.regexpctl,regexpesc:e.regexpesc,tokenizer:e.tokenizer};export{d as conf,c as language};
//# sourceMappingURL=javascript-CwdHeu9b.js.map
