.table-card[data-v-eb2ff5e4]{height:100%;width:100%;transition:all .3s ease}.table-card[data-v-eb2ff5e4]:hover{transform:translateY(-2px);box-shadow:0 4px 12px var(--ac-shadow-color)}.columns-list[data-v-eb2ff5e4]{max-height:280px;overflow-y:auto;overflow-x:hidden}.column-row[data-v-eb2ff5e4]{padding:4px 0;position:relative;min-width:0;transition:all .2s ease}.column-highlighted[data-v-eb2ff5e4],.more-columns-highlighted[data-v-eb2ff5e4]{background-color:var(--ac-bg-hover)}.table-highlighted[data-v-eb2ff5e4]{border:2px solid var(--ac-brand-link);box-shadow:0 0 0 2px #1890ff33}.key-icon[data-v-eb2ff5e4]{color:#faad14;flex-shrink:0}.delete-btn[data-v-eb2ff5e4]{opacity:0;background:none;border:none;padding:4px;cursor:pointer;color:var(--ac-text-tertiary);border-radius:4px;display:flex;align-items:center;justify-content:center;transition:all .2s ease}.delete-btn[data-v-eb2ff5e4]:hover{color:#ef4444;background-color:#fee2e2}.table-card:hover .delete-btn[data-v-eb2ff5e4]{opacity:1}.type-tag[data-v-eb2ff5e4]{font-size:11px;padding:0 8px;margin:0;border-radius:4px;white-space:nowrap;flex-shrink:0}
