import{e as c,b,n as r,g as d,p as a,A as g,w as n,v as l,B as i,y as p,D as m,E as u,h as f,j as y,m as B}from"./jwt-decode.esm-CzNJpMna.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e19a83cd-8b79-4477-a9b4-4f657621f89a",e._sentryDebugIdIdentifier="sentry-dbid-e19a83cd-8b79-4477-a9b4-4f657621f89a")}catch{}})();const w=c({__name:"AbstraButton",props:{disabledTooltip:{},tooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(e){const t=b(()=>o.disabledTooltip&&o.disabled?o.disabledTooltip:o.tooltip),o=e;return(s,k)=>t.value?(d(),r(a(g),{key:0,title:t.value},{default:n(()=>[l(a(i),p(m(s.$props)),{default:n(()=>[l(a(u),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:n(()=>[e.loading?y("",!0):f(s.$slots,"default",{key:0})]),_:3})]),_:3},16)]),_:3},8,["title"])):(d(),r(a(i),p(B({key:1},s.$props)),{default:n(()=>[l(a(u),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:n(()=>[e.loading?y("",!0):f(s.$slots,"default",{key:0})]),_:3})]),_:3},16))}});export{w as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang-Bb3vA821.js.map
