import{ab as b,ac as n}from"./jwt-decode.esm-CzNJpMna.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="8b954790-9e3c-4d2c-8b3a-e385ecd111ae",e._sentryDebugIdIdentifier="sentry-dbid-8b954790-9e3c-4d2c-8b3a-e385ecd111ae")}catch{}})();function c(e){return n.isArray(e)?e.length===0?"[ ]":"[ ... ]":n.isObject(e)?Object.keys(e).length===0?"{ }":"{ ... }":n.isString(e)?`'${e}'`:n.isUndefined(e)||n.isNull(e)?"None":e===!0?"True":e===!1?"False":`${e}`}function f(e){if(n.isArray(e))return"array";if(n.isObject(e))return"object";throw new Error("treeKey called with non-object and non-array")}function u(e,r=[],i){const l=i?`'${i}': ${c(e)}`:c(e);if(n.isArray(e)){const t=f(e);return[{title:l,key:[...r,t].join("/"),rawData:e,children:e.flatMap((s,o)=>u(s,[...r,t,`${o}`]))}]}else if(n.isObject(e)){const t=f(e);return[{title:l,key:[...r,t].join("/"),rawData:e,children:Object.entries(e).flatMap(([s,o])=>u(o,[...r,t,s],s))}]}else return[{title:l,key:r.join("/"),rawData:e,children:[]}]}function w(e,r){return new Promise(i=>{b.confirm({title:e,onOk:()=>i(!0),okText:r?.okText,onCancel:()=>i(!1),cancelText:r?.cancelText})})}export{w as a,u as t};
//# sourceMappingURL=ant-design-YNQprZ_s.js.map
