import{e as _,ag as p,ak as m,l as s,n as f,g as i,w as u,f as g,O as y,Z as v,v as k,p as n,k as w,t as I}from"./jwt-decode.esm-CzNJpMna.js";import{u as T}from"./projectStore-1e9Bdcb1.js";import{A as D,T as S}from"./index-zwdtp9eM.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="80023684-38e8-455b-add0-ce165906ba71",e._sentryDebugIdIdentifier="sentry-dbid-80023684-38e8-455b-add0-ce165906ba71")}catch{}})();const N=_({__name:"TablesTabs",setup(e){const a=p(),r=m(),c=String(r.name),d=T(),o=[{label:s.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:s.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:s.translate("i18n_tablestabs_run_sql"),value:"sql"}],b=l=>{a.push({name:String(l),params:{projectId:d.projectId}})};return(l,h)=>(i(),f(n(S),{"active-key":n(c),options:o,"onUpdate:activeKey":b},{default:u(()=>[(i(),g(y,null,v(o,t=>k(n(D),{key:t.value,name:t.value},{tab:u(()=>[w("span",null,I(t.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{N as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-WHEGC8Qr.js.map
