import{aX as r,aY as n,a7 as o,aZ as p,a_ as c,a$ as d,b0 as f,b1 as m,b2 as b,b3 as s,b4 as u,b5 as g,b6 as l}from"./jwt-decode.esm-CzNJpMna.js";import{b as y,s as w,g as _}from"./workspaceStore-CfaRGIsm.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang-DU9xf-3K.js";import{r as i}from"./router-8Vfxs13r.js";import"./userStore-awX4g_0u.js";import"./runnerData-y7ODBKD6.js";import"./url-DUHlB_Eu.js";import"./colorHelpers-DqllhzUB.js";import"./PlayerConfigProvider-B_tg2hYa.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="097c9f12-5b3e-4782-a400-054365d2e5fa",t._sentryDebugIdIdentifier="sentry-dbid-097c9f12-5b3e-4782-a400-054365d2e5fa")}catch{}})();class I{static init(){setInterval(()=>{y("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await _(),a=r(),e=n({render:()=>o(h)});p.init(),c(e,i,t),I.init(),e.use(i),e.use(a),e.use(d),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",m),e.component("Message",b),s(e,u),s(e,g),s(e,l)})();
//# sourceMappingURL=player-B4ts431F.js.map
