import{_ as o,d}from"./NewEditor-llqQDWrH.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="97347ed0-97f9-4ef7-9d25-3eef779e8354",e._sentryDebugIdIdentifier="sentry-dbid-97347ed0-97f9-4ef7-9d25-3eef779e8354")}catch{}})();var a=o((e,n)=>{let t;return n==="sandbox"&&(t=d("#i"+e)),(n==="sandbox"?d(t.nodes()[0].contentDocument.body):d("body")).select(`[id="${e}"]`)},"getDiagramElement");export{a as g};
//# sourceMappingURL=chunk-55IACEB6-DKaMxZox.js.map
