import"./jwt-decode.esm-CzNJpMna.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="23a6dd4a-f06a-4898-9465-0203121f0992",e._sentryDebugIdIdentifier="sentry-dbid-23a6dd4a-f06a-4898-9465-0203121f0992")}catch{}})();function d(e,t){return e.toLocaleString(void 0,{hour12:!1,timeZoneName:"short",day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit",weekday:"long",...t})}function a(e){return new Intl.DateTimeFormat(navigator.language,{day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit"}).format(new Date(e))}export{a as f,d as g};
//# sourceMappingURL=datetime-X9kH9YTn.js.map
