import{A as n}from"./index-BAbb188Z.js";import{e as a,b as o,f as r,j as f,K as c,v as d,p as l,g as p,aO as i}from"./jwt-decode.esm-CzNJpMna.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="7febdec4-80ad-4671-9ba5-9f3094bb30b8",e._sentryDebugIdIdentifier="sentry-dbid-7febdec4-80ad-4671-9ba5-9f3094bb30b8")}catch{}})();const u=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=o(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(b,m)=>e.stepsInfo?(p(),r("nav",{key:0,class:c(["p-steps",{"full-screen":!e.isPreview}])},[d(l(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):f("",!0)}}),v=i(u,[["__scopeId","data-v-58fdd395"]]);export{v as S};
//# sourceMappingURL=Steps-DzcCu8nY.js.map
