.connector-card[data-v-86187920]{cursor:pointer;transition:all .3s}.connector-card[data-v-86187920]:hover{box-shadow:0 0 15px #0000001a}.connector-card.unavailable[data-v-86187920]{opacity:.7}.connector-card.unavailable[data-v-86187920]:hover{box-shadow:none}.connectors-grid[data-v-232d4d34]{display:grid;grid-template-columns:repeat(auto-fill,minmax(300px,1fr));gap:20px}.connector-search[data-v-232d4d34]{width:300px;margin-bottom:40px}.connector-search[data-v-232d4d34] .ant-input{border-color:var(--ac-border-primary)}.connector-search[data-v-232d4d34] .ant-input-search-button{background-color:var(--ac-brand-primary);border-color:var(--ac-brand-primary)}.connector-search[data-v-232d4d34] .ant-input-search-button .anticon{color:#fff}.connector-search[data-v-232d4d34] .ant-input-search-button:hover{background-color:var(--ac-brand-primary);border-color:var(--ac-brand-primary);opacity:.85}
