import{C as f,T as m}from"./router-W58Zb32N.js";import{e as u,b as y,l as d,n as i,j as b,g as r,p as s,w as t,B as g,q as l,t as o,v as p,T as _}from"./jwt-decode.esm-CzNJpMna.js";import{A as k}from"./index-BCLTAqIZ.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="4c825082-de3d-4589-9fe6-c262ae5af67e",e._sentryDebugIdIdentifier="sentry-dbid-4c825082-de3d-4589-9fe6-c262ae5af67e")}catch{}})();const M=u({__name:"BillingAlert",props:{organizationId:{},billingMetadata:{}},setup(e){const a=e,n=y(()=>a.billingMetadata?.messageCTA??d.translate("i18n_billingalert_contact_us")),c=()=>{f.showNewMessage(d.translate("i18n_billingalert_help_message")),m.billingAlertCtaClicked(a.organizationId,n.value)};return(C,w)=>e.billingMetadata?.message?(r(),i(s(k),{key:0,type:"error"},{message:t(()=>[p(s(_),{type:"secondary"},{default:t(()=>[l(o(e.billingMetadata?.message),1)]),_:1})]),action:t(()=>[e.billingMetadata?.messageLink?(r(),i(s(g),{key:0,type:"primary",target:"_blank",href:e.billingMetadata.messageLink},{default:t(()=>[l(o(n.value),1)]),_:1},8,["href"])):(r(),i(s(g),{key:1,type:"primary",onClick:c},{default:t(()=>[l(o(n.value),1)]),_:1}))]),_:1})):b("",!0)}});export{M as _};
//# sourceMappingURL=BillingAlert.vue_vue_type_script_setup_true_lang-iu_WJdY7.js.map
