import{O as l}from"./workspaceStore-CfaRGIsm.js";import{e as c,S as f,f as u,v as n,w as o,p as a,am as _,T as p,q as r,t as i,l as s,g as b}from"./jwt-decode.esm-CzNJpMna.js";import"./userStore-awX4g_0u.js";import"./runnerData-y7ODBKD6.js";import"./url-DUHlB_Eu.js";import"./colorHelpers-DqllhzUB.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b12fd108-c66c-42bf-8783-33930cd435f3",e._sentryDebugIdIdentifier="sentry-dbid-b12fd108-c66c-42bf-8783-33930cd435f3")}catch{}})();const D=c({__name:"OidcLoginCallback",setup(e){return f(async()=>{await new l().loginCallback()}),(t,d)=>(b(),u("div",null,[n(a(_),null,{default:o(()=>[r(i(a(s).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(a(p),null,{default:o(()=>[r(i(a(s).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLoginCallback-BHD9E21g.js.map
