import{e as i,b as n,f as d,g as u,K as a,M as o,k as c,h as f}from"./jwt-decode.esm-CzNJpMna.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="246c3b89-7b9d-4604-bb3a-ca34f4baf617",e._sentryDebugIdIdentifier="sentry-dbid-246c3b89-7b9d-4604-bb3a-ca34f4baf617")}catch{}})();const p=i({__name:"ScrollArea",props:{innerClass:{},outerClass:{},outerStyle:{},innerStyle:{}},setup(e){const t=e,s=n(()=>t.outerStyle?{position:"relative",...t.outerStyle}:{position:"relative"}),r=n(()=>({position:"absolute",inset:0,overflow:"auto",...t.innerStyle??{}}));return(l,b)=>(u(),d("div",{style:o(s.value),class:a(e.outerClass)},[c("div",{style:o(r.value),class:a(e.innerClass)},[f(l.$slots,"default")],6)],6))}});export{p as _};
//# sourceMappingURL=ScrollArea.vue_vue_type_script_setup_true_lang-CWnNlTIt.js.map
