(function(){try{var I=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(I._sentryDebugIds=I._sentryDebugIds||{},I._sentryDebugIds[e]="0cff5f6d-8455-4e5e-8c81-4923156972ac",I._sentryDebugIdIdentifier="sentry-dbid-0cff5f6d-8455-4e5e-8c81-4923156972ac")}catch{}})();var _={PRE_SUBJECT:0,WRITING_SUB_URI:1,WRITING_BNODE_URI:2,PRE_PRED:3,WRITING_PRED_URI:4,PRE_OBJ:5,WRITING_OBJ_URI:6,WRITING_OBJ_BNODE:7,WRITING_OBJ_LITERAL:8,WRITING_LIT_LANG:9,WRITING_LIT_TYPE:10,POST_OBJ:11,ERROR:12};function f(I,e){var n=I.location,i;n==_.PRE_SUBJECT&&e=="<"?i=_.WRITING_SUB_URI:n==_.PRE_SUBJECT&&e=="_"?i=_.WRITING_BNODE_URI:n==_.PRE_PRED&&e=="<"?i=_.WRITING_PRED_URI:n==_.PRE_OBJ&&e=="<"?i=_.WRITING_OBJ_URI:n==_.PRE_OBJ&&e=="_"?i=_.WRITING_OBJ_BNODE:n==_.PRE_OBJ&&e=='"'?i=_.WRITING_OBJ_LITERAL:n==_.WRITING_SUB_URI&&e==">"||n==_.WRITING_BNODE_URI&&e==" "?i=_.PRE_PRED:n==_.WRITING_PRED_URI&&e==">"?i=_.PRE_OBJ:n==_.WRITING_OBJ_URI&&e==">"||n==_.WRITING_OBJ_BNODE&&e==" "||n==_.WRITING_OBJ_LITERAL&&e=='"'||n==_.WRITING_LIT_LANG&&e==" "||n==_.WRITING_LIT_TYPE&&e==">"?i=_.POST_OBJ:n==_.WRITING_OBJ_LITERAL&&e=="@"?i=_.WRITING_LIT_LANG:n==_.WRITING_OBJ_LITERAL&&e=="^"?i=_.WRITING_LIT_TYPE:e==" "&&(n==_.PRE_SUBJECT||n==_.PRE_PRED||n==_.PRE_OBJ||n==_.POST_OBJ)?i=n:n==_.POST_OBJ&&e=="."?i=_.PRE_SUBJECT:i=_.ERROR,I.location=i}const E={name:"ntriples",startState:function(){return{location:_.PRE_SUBJECT,uris:[],anchors:[],bnodes:[],langs:[],types:[]}},token:function(I,e){var n=I.next();if(n=="<"){f(e,n);var i="";return I.eatWhile(function(R){return R!="#"&&R!=">"?(i+=R,!0):!1}),e.uris.push(i),I.match("#",!1)||(I.next(),f(e,">")),"variable"}if(n=="#"){var r="";return I.eatWhile(function(R){return R!=">"&&R!=" "?(r+=R,!0):!1}),e.anchors.push(r),"url"}if(n==">")return f(e,">"),"variable";if(n=="_"){f(e,n);var T="";return I.eatWhile(function(R){return R!=" "?(T+=R,!0):!1}),e.bnodes.push(T),I.next(),f(e," "),"builtin"}if(n=='"')return f(e,n),I.eatWhile(function(R){return R!='"'}),I.next(),I.peek()!="@"&&I.peek()!="^"&&f(e,'"'),"string";if(n=="@"){f(e,"@");var u="";return I.eatWhile(function(R){return R!=" "?(u+=R,!0):!1}),e.langs.push(u),I.next(),f(e," "),"string.special"}if(n=="^"){I.next(),f(e,"^");var l="";return I.eatWhile(function(R){return R!=">"?(l+=R,!0):!1}),e.types.push(l),I.next(),f(e,">"),"variable"}n==" "&&f(e,n),n=="."&&f(e,n)}};export{E as ntriples};
//# sourceMappingURL=ntriples-Cyqtyzzp.js.map
