const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-BHD9E21g.js","assets/workspaceStore-CfaRGIsm.js","assets/jwt-decode.esm-CzNJpMna.js","assets/jwt-decode-D9gGYFRj.css","assets/userStore-awX4g_0u.js","assets/runnerData-y7ODBKD6.js","assets/url-DUHlB_Eu.js","assets/colorHelpers-DqllhzUB.js","assets/OidcLogoutCallback-BhjUipkD.js","assets/Login-DmBC6DKY.js","assets/Login.vue_vue_type_script_setup_true_lang-u4ZN7l_q.js","assets/OTPInput-B7MPU8vI.js","assets/OTPInput-DkitIIgo.css","assets/Logo-DoFepIVD.js","assets/Logo-D2kepPyK.css","assets/string-KT3da_dt.js","assets/CircularLoading-CkYtte64.js","assets/CircularLoading-BiyobKo3.css","assets/index-BCLTAqIZ.js","assets/Login-D3Bo1XNf.css","assets/Login-CobhrWJT.css","assets/Main-BtkmpWCN.js","assets/PlayerNavbar-BeDxMJcv.js","assets/metadata-0JQnRzMV.js","assets/PhCursorClick.vue-BJXHzSPd.js","assets/PhHouse.vue-CSPrR4xv.js","assets/PhMagnifyingGlass.vue-BGNgpZ6K.js","assets/PhWebhooksLogo.vue-BuSFJJka.js","assets/LoadingOutlined-C_g2Yr72.js","assets/PhSignOut.vue-BpDijczZ.js","assets/index-DvntD8BL.js","assets/PlayerNavbar-DAUZYUrK.css","assets/Main-q9PQMe3g.css","assets/Home-DzI1KNBe.js","assets/Watermark-BVgdxgEk.js","assets/constants-CmgnxxPp.js","assets/Watermark-Fl_4jwe9.css","assets/PageStageView-BCgPEw6p.js","assets/PageStageView-Di2X0Z7S.css","assets/PhArrowSquareOut.vue-BidOwVXL.js","assets/index-zwdtp9eM.js","assets/Home-letY2zGI.css","assets/Error-B5B2DtcN.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-e-lImNC1.js","assets/logo-BiWG9_W5.js","assets/Error-CIbhyrKS.css","assets/Form-C5McJJBF.js","assets/FormRunner-CsTGVCQw.js","assets/Steps-DzcCu8nY.js","assets/index-BAbb188Z.js","assets/Steps-D24tH1sk.css","assets/FormRunner-Cr_m7D0_.css","assets/redirect-DosoxBtq.js","assets/asyncComputed-tYnPAAjo.js","assets/uuid-B4_ctPXu.js","assets/Form-TwePofFo.css"])))=>i.map(i=>d[i]);
import{c as u,a as d,_ as t,u as l}from"./jwt-decode.esm-CzNJpMna.js";import{u as p}from"./userStore-awX4g_0u.js";import{a as _}from"./workspaceStore-CfaRGIsm.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="cf5accf6-aeb8-4ec9-818d-b0c15c139299",e._sentryDebugIdIdentifier="sentry-dbid-cf5accf6-aeb8-4ec9-818d-b0c15c139299")}catch{}})();const h=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-BHD9E21g.js"),__vite__mapDeps([0,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-BhjUipkD.js"),__vite__mapDeps([8,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-DmBC6DKY.js"),__vite__mapDeps([9,10,2,3,1,4,5,6,7,11,12,13,14,15,16,17,18,19,20])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-BtkmpWCN.js"),__vite__mapDeps([21,22,4,2,3,1,5,6,7,23,24,25,26,27,28,29,30,31,32])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-DzI1KNBe.js"),__vite__mapDeps([33,23,24,2,3,25,26,27,34,1,4,5,6,7,35,36,37,16,17,38,39,40,28,41])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-B5B2DtcN.js"),__vite__mapDeps([42,43,44,13,2,3,14,35,1,4,5,6,7,40,45])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-C5McJJBF.js"),__vite__mapDeps([46,4,2,3,37,16,17,34,1,5,6,7,35,36,38,47,10,11,12,13,14,15,18,19,48,49,50,51,52,53,54,55])),meta:{hideLogin:!0}}]}],i=u({history:d("/"),routes:h,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),f=e=>async(a,o)=>{if(l(a,o),a.meta.allowUnauthenticated)return;const r=p();r.loadJWT();const c=await _(a.path),{redirect:s,...m}=a.query;switch(c.status){case"ALLOWED":break;case"UNAUTHORIZED":{const n=r.email;r.removeJWT(),await e.push({name:"playerLogin",query:{...m,redirect:s||a.path,reauth:n?"true":void 0,email:n||void 0},params:a.params});break}case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};i.beforeEach(f(i));export{h as a,f as g,i as r};
//# sourceMappingURL=router-8Vfxs13r.js.map
