import{B as l}from"./BaseLayout-DB8SD_oU.js";import{C as p}from"./ContentLayout-Cco-2V__.js";import{e as f,ak as _,b as i,H as b,a6 as g,n as r,g as s,w as d,v as y,j as w}from"./jwt-decode.esm-CzNJpMna.js";import{_ as v}from"./BillingAlert.vue_vue_type_script_setup_true_lang-iu_WJdY7.js";import{u as z}from"./projectsStore-Bh6FoGp2.js";import"./router-W58Zb32N.js";import"./ts.worker-yzRZJ3oC.js";import"./index-BCLTAqIZ.js";import"./member-DZQbFOdZ.js";import"./organization-Dv2gjYZs.js";import"./project-CUN2uQd6.js";import"./tables-B14bH8Kr.js";import"./string-KT3da_dt.js";import"./cascaderStore-foIVwCGb.js";import"./organizationSwitcher-CIDAicHA.js";import"./ant-design-YNQprZ_s.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="4646b1a2-1e84-4a36-8ed9-289b1a4be9f5",t._sentryDebugIdIdentifier="sentry-dbid-4646b1a2-1e84-4a36-8ed9-289b1a4be9f5")}catch{}})();const P=f({__name:"Organization",setup(t){const e=_(),a=z(),n=i(()=>e.params.organizationId);b(n,o=>{o&&a.fetchedState?.organization?.id!==o&&a.fetchState(o)},{immediate:!0});const u=i(()=>a.fetchedState?.organization),m=i(()=>u.value?.billingMetadata);return(o,h)=>{const c=g("RouterView");return s(),r(l,null,{content:d(()=>[y(p,null,{default:d(()=>[m.value?(s(),r(v,{key:0,"billing-metadata":m.value,"organization-id":n.value},null,8,["billing-metadata","organization-id"])):w("",!0),(s(),r(c,{key:n.value}))]),_:1})]),_:1})}}});export{P as default};
//# sourceMappingURL=Organization-DjyCZcX9.js.map
