import{i as o}from"./url-DUHlB_Eu.js";import"./jwt-decode.esm-CzNJpMna.js";import{i as u}from"./colorHelpers-DqllhzUB.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="690df47d-522f-4944-947c-3a87b8d4c8c7",e._sentryDebugIdIdentifier="sentry-dbid-690df47d-522f-4944-947c-3a87b8d4c8c7")}catch{}})();function s(e,a,r){return o(a)?a:r==="player"?`/_assets/${e}`:`/_editor/api/assets/${a}`}const n="#414a58",t="#FFFFFF",c="#000000",l="DM Sans",_="Untitled Project",i={value:"en"};function p(e){return{id:e.id,path:e.path,theme:e.workspace.theme??t,brandName:e.workspace.brand_name??null,title:e.title,isInitial:e.is_initial,isLocal:e.is_local??!1,startMessage:e.start_message??null,endMessage:e.end_message??null,errorMessage:e.error_message??null,timeoutMessage:e.timeout_message??null,startButtonText:e.start_button_text??null,logoUrl:e.workspace.logo_url,mainColor:e.workspace.main_color??n,fontFamily:e.workspace.font_family??l,autoStart:e.auto_start??!1,runtimeType:"form",language:e.workspace.language??i.value,sidebar:e.workspace?.sidebar??[]}}function b(e){return{id:e.id,path:e.path,title:e.title,runtimeType:"page",sidebar:e.workspace?.sidebar??[]}}function y(e){const a=e.theme??t;return{name:e.name||_,fontColor:e.font_color||c,sidebar:e.sidebar||[],brandName:e.brand_name||"",fontFamily:e.font_family||l,logoUrl:e.logo_url?s("logo",e.logo_url,"player"):null,mainColor:e.main_color||n,theme:u(a)?a:s("background",a,"player"),language:e.language||i.value}}export{n as D,l as a,i as b,t as c,s as m,b as p,p as r,y as w};
//# sourceMappingURL=runnerData-y7ODBKD6.js.map
