import{C as t,_ as p}from"./View.vue_vue_type_script_setup_true_lang-CNYpsRm2.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-CzNJpMna.js";import{u as a}from"./projectStore-1e9Bdcb1.js";import"./router-W58Zb32N.js";import"./ts.worker-yzRZJ3oC.js";import"./fetch-THx6uYpD.js";import"./tables-B14bH8Kr.js";import"./string-KT3da_dt.js";import"./SaveButton-BzqbycQT.js";import"./ExclamationCircleOutlined-B2yXPxfh.js";import"./CrudView-CBAtMKH_.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-C7GobnYl.js";import"./constants-CmgnxxPp.js";import"./url-DUHlB_Eu.js";import"./PhDotsThreeVertical.vue-CFZozSgS.js";import"./index-2y0Q0tZ3.js";import"./asyncComputed-tYnPAAjo.js";import"./PhPencil.vue-BdquHkzg.js";import"./useCodebaseEvents-BuuUH-Ws.js";import"./contracts.generated-BZkyx5I1.js";import"./index-BCLTAqIZ.js";import"./project-CUN2uQd6.js";import"./organizationSwitcher-CIDAicHA.js";import"./organization-Dv2gjYZs.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="811ad987-b710-4d48-8aa4-fe38ed0102d2",o._sentryDebugIdIdentifier="sentry-dbid-811ad987-b710-4d48-8aa4-fe38ed0102d2")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=a(),e=new t(r.projectId);return(d,f)=>(s(),n(p,{"env-var-repository":m(e),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-CTEE2szj.js.map
