import{_ as c}from"./Login.vue_vue_type_script_setup_true_lang-u4ZN7l_q.js";import{e as d,f as i,v as u,p as n,ag as m,ak as f,g as l,aO as b}from"./jwt-decode.esm-CzNJpMna.js";import{u as _}from"./workspaceStore-CfaRGIsm.js";import"./OTPInput-B7MPU8vI.js";import"./Logo-DoFepIVD.js";import"./string-KT3da_dt.js";import"./CircularLoading-CkYtte64.js";import"./index-BCLTAqIZ.js";import"./userStore-awX4g_0u.js";import"./runnerData-y7ODBKD6.js";import"./url-DUHlB_Eu.js";import"./colorHelpers-DqllhzUB.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="8191bbab-69bd-49fb-aa19-5ab8d1ee8dfb",e._sentryDebugIdIdentifier="sentry-dbid-8191bbab-69bd-49fb-aa19-5ab8d1ee8dfb")}catch{}})();const g={class:"runner"},y=d({__name:"Login",setup(e){const o=m(),a=f(),r=_(),p=async()=>{const{redirect:t,...s}=a.query;if(t){await o.push({path:t,query:s,params:a.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>(l(),i("div",g,[u(c,{"logo-url":n(r).state.workspace?.logoUrl??void 0,"brand-name":n(r).state.workspace?.brandName,locale:n(r).state.workspace?.language??"en",onDone:p},null,8,["logo-url","brand-name","locale"])]))}}),R=b(y,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-DmBC6DKY.js.map
