.page-wrapper[data-v-e814c839]{width:100%;height:100%}.home-container[data-v-e814c839]{width:100%;height:100%;overflow:auto;display:flex;flex-direction:column;align-items:center}.cards-container[data-v-e814c839]{width:fit-content;justify-content:center;align-items:center;padding:80px 0}.form-card[data-v-e814c839]{cursor:pointer;width:100%;background-color:var(--background-color-main)}.form-card[data-v-e814c839]:hover{box-shadow:0 0 10px 0 var(--ac-shadow-color)}.form-card.loading[data-v-e814c839]{opacity:.8;pointer-events:none}
