(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="a9ada4db-85bd-47ea-8ad0-3ef3f4873bdf",e._sentryDebugIdIdentifier="sentry-dbid-a9ada4db-85bd-47ea-8ad0-3ef3f4873bdf")}catch{}})();var i="><+-.,[]".split("");const r={name:"brainfuck",startState:function(){return{commentLine:!1,left:0,right:0,commentLoop:!1}},token:function(e,n){if(e.eatSpace())return null;e.sol()&&(n.commentLine=!1);var f=e.next().toString();if(i.indexOf(f)!==-1){if(n.commentLine===!0)return e.eol()&&(n.commentLine=!1),"comment";if(f==="]"||f==="[")return f==="["?n.left++:n.right++,"bracket";if(f==="+"||f==="-")return"keyword";if(f==="<"||f===">")return"atom";if(f==="."||f===",")return"def"}else return n.commentLine=!0,e.eol()&&(n.commentLine=!1),"comment";e.eol()&&(n.commentLine=!1)}};export{r as brainfuck};
//# sourceMappingURL=brainfuck--9lT9I8p.js.map
